use bevy::{core_pipeline::bloom::Bloom, prelude::*};

use crate::{player::Player, CAMERA_DECAY_RATE};

#[derive(Debug, Component)]
pub struct UserCamera;

impl UserCamera {
    pub fn setup(mut commands: Commands) {
        commands.spawn((
            Camera2d,
            Camera {
                hdr: true,
                ..default()
            },
            Bloom::NATURAL,
        ));
    }

    pub fn update(
        mut camera: Query<&mut Transform, (With<Camera2d>, Without<Player>)>,
        player: Query<&Transform, (With<Player>, Without<Camera2d>)>,
        time: Res<Time>,
    ) {
        let mut camera = camera.get_single_mut().unwrap();
        let player = player.get_single().unwrap();

        let Vec3 { x, y, .. } = player.translation;
        let direction = Vec3::new(x, y, camera.translation.z);

        camera
            .translation
            .smooth_nudge(&direction, CAMERA_DECAY_RATE, time.delta_secs());
    }
}
