use bevy::{
    app::{App, Startup, Update},
    diagnostic::FrameTimeDiagnosticsPlugin,
    DefaultPlugins,
};
use camera::UserCamera;
use player::Player;
use ui::{FPSText, FishCounterText, KeybindingsText};
use water::Water;

mod camera;
mod player;
mod ui;
mod water;

pub const CHARACTER_SPEED: f32 = 300.0;
pub const CAMERA_DECAY_RATE: f32 = 3.0;
pub const FISHING_AREA_RADIUS: f32 = 100.0;

pub fn start_game() {
    App::new()
        .add_plugins(DefaultPlugins)
        .add_plugins(FrameTimeDiagnosticsPlugin)
        .add_systems(
            Startup,
            (
                FPSText::setup,
                UserCamera::setup,
                Water::setup,
                Player::setup,
                FishCounterText::setup,
                KeybindingsText::setup,
            ),
        )
        .add_systems(
            Update,
            (
                FPSText::update,
                UserCamera::update,
                Player::r#move,
                Water::fishing,
                FishCounterText::update,
            ),
        )
        .run();
}
